@@ -5,6 +5,7 @@ Encode and emberder spectra.
 """
 
 import os
+import sys
 
 import more_itertools
 from pyteomics.mgf import read as mgf_read
@@ -720,7 +721,7 @@ class EmbedDataset:
 
         vstack_data_df = pd.DataFrame({"embedded_spectra": self.out_list.tolist()})
         self.ids_vstack_df = pd.concat([ids_data, vstack_data_df], axis=1)
-        self.ids_vstack_df.to_csv(store_embed_file, header=True, index=None, columns=["ids", "embedded_spectra"])
+        self.ids_vstack_df.to_csv(store_embed_file, sep="\t", header=True, index=None, columns=["ids", "embedded_spectra"])
 
 
 def encode_spectra(prj, input_file, reference_spectra,  **kw):
@@ -827,3 +828,4 @@ def encode_and_embed_spectra(model, prj, input_file, refrence_spectra):
     ids_usi_df, vstack_encoded_spectra = encode_spectra(prj, input_file, refrence_spectra)
     embed_spectra(model, ids_usi_df, vstack_encoded_spectra, output_embedded_file)
 
+
